pub struct EntityRotationSyncState {
last_body_rotation: PackedEntityRotation,
last_head_yaw: i8,
}Expand description
Last packed rotation values known to tracking clients.
Fields
last_body_rotation: PackedEntityRotationlast_head_yaw: i8Implementations
Sourceimpl EntityRotationSyncState
impl EntityRotationSyncState
Sourcepub const fn new(body_rotation: (f32, f32), head_yaw: f32) -> Self
pub const fn new(body_rotation: (f32, f32), head_yaw: f32) -> Self
Creates rotation sync state for values already known to tracking clients.
Sourcepub fn record_body_rotation(
&mut self,
rotation: (f32, f32),
) -> Option<PackedEntityRotation>
pub fn record_body_rotation( &mut self, rotation: (f32, f32), ) -> Option<PackedEntityRotation>
Records a body rotation packet if the packed yaw or pitch changed.
Sourcepub fn body_rotation_changed(self, rotation: (f32, f32)) -> bool
pub fn body_rotation_changed(self, rotation: (f32, f32)) -> bool
Returns whether packed body yaw or pitch changed since the last sync.
Sourcepub const fn mark_body_rotation_sent(&mut self, rotation: (f32, f32))
pub const fn mark_body_rotation_sent(&mut self, rotation: (f32, f32))
Marks a body rotation as sent because a full position sync includes it.
Sourcepub const fn record_head_yaw(&mut self, head_yaw: f32) -> Option<i8>
pub const fn record_head_yaw(&mut self, head_yaw: f32) -> Option<i8>
Records a head-rotation packet if the packed yaw changed.